Exception: Speck::Exception

Inherits:
StandardError
  • Object
show all
Defined in:
lib/speck.rb

Overview

A root class, and container class, for Speck exceptions.

Constant Summary collapse

CheckFailed =

Raised when a Check fails

Class.new self
EnvironmentConflict =

Raised when you attempt to stack an environment contrary to the existing environment

Class.new self